@@ -1,16 +1,18 @@
 #!/usr/bin/env node
 
-import { readFile, writeFile } from 'fs/promises'
-import { fileURLToPath } from 'url'
+import { readFile, writeFile } from 'node:fs/promises'
+import { join } from 'node:path'
 import { minify } from 'terser'
-import { join } from 'path'
 
-const ROOT = join(fileURLToPath(import.meta.url), '..', '..')
+import { urlAlphabet } from '../url-alphabet/index.js'
+
+const ROOT = join(import.meta.dirname, '..')
 
 async function build() {
   let js = await readFile(join(ROOT, 'index.browser.js'))
   let func = js.toString().match(/(export let nanoid [\W\w]*$)/)[1]
-  let { code } = await minify(func)
+  let all = `let a = '${urlAlphabet}'\n${func.replaceAll('urlAlphabet', 'a')}`
+  let { code } = await minify(all)
   await writeFile(join(ROOT, 'nanoid.js'), code)
 }
 
